@@ -33,9 +33,10 @@
 #  define KIOCORE_DEPRECATED_NO_EXPORT KIOCORE_NO_EXPORT KIOCORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KIOCORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KIOCORE_NO_DEPRECATED
+#    define KIOCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
